# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-10-17 14:24
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('certification', '0001_initial'),
    ]

    operations = [
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2019-06-27 14:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('certification', '0005_auto_20190627_1404'),
    ]

    operations = [
        migrations.AddField(
            model_name='certificationgroup',
            name='instructor_name',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
